@@ -2,6 +2,9 @@ from .imports import *
 from .foundation import *
 from .dispatch import *
 from .utils import *
+from .helpers import *
+from .parallel import *
+from .net import *
 from .transform import *
 from .test import *
 from .meta import *
